@@ -1,8 +1,12 @@
 #[cfg(feature = "globset")]
 mod for_globset;
+#[cfg(feature = "lsp-types")]
+mod for_lsp;
 #[cfg(feature = "num")]
 mod for_num;
 #[cfg(feature = "pest")]
 mod for_pest;
 #[cfg(feature = "rsass")]
 mod for_sass;
+#[cfg(feature = "chrono")]
+mod for_time;
